==> campsite-2.4.1.tbz: campsite/www-common/html/priv/lang/pt/api.php <==
<?php
regGS("Cannot create file \"$1\"", "Não é possivél criar o ficheiro \"$1\"");
regGS("The IP address group $1 has been deleted.", "O grupo de ip's $1 foi eliminado.");
regGS("IP Group $1 added for user $2", "O grupo de ip's $1 foi adicionado para o utilizador $2");
regGS("User permissions for $1 changed", "As permissões para o utilizador $1 foram alteradas");
regGS("Section $1 deleted. (Issue: $2, Publication: $3)", "Secção $1 eliminada. (Edição $2, Publicação: $3)");
regGS("Section $1 added. (Issue: $2, Publication: $3)", "Secção $1 adicionada. (Edição $2, Publicação: $3)");
regGS("Issue $1 changed status to $2", "O Estado da edição $1 foi alterado para $2");
regGS("User type $1 deleted", "Tipo de utilizador $1 eliminado.");
regGS("User type $1 added", "Tipo de utilizador $1 adicionado.");
regGS("Topic $1 added to article", "Tema $1 foi adicionado ao artigo");
regGS("Last", "Ultimo");
regGS("First", "Primeiro");
regGS("Changed image properties of $1", "Alterando as informações da imagem $1");
regGS("Article topic $1 deleted", "O tema $1 do artigo foi eliminado");
regGS("Article #$1 \"$2\" ($3) created.", "Artigo #$1 \"$2\" ($3) criado.");
regGS("Article #$1 \"$2\" ($3) translated to \"$5\" ($4)", "Artigo #$1 \"$2\" ($3) traduzido para \"$5\" ($4)");
regGS("Article #$1 \"$2\" ($3) copied to Article #$3. ", "Artigo #$1 \"$2\" ($3) copiado para #$3.");
regGS("Article #$1: \"$2\" status changed from $3 to $4.", "Estado do Artigo #$1: \"$2\" alterado de $3 para $4.");
regGS("Article #$1: \"$2\" ($3) deleted.", "Artigo #$1: \"$2\" ($3) eliminado.");
regGS("Text", "Texto");
regGS("Article body", "Corpo do artigo");
regGS("The default subscription time for $1 has been added.", "Foi adiciondo um tempo de Assinatura para $1 ");
regGS("Image $1 linked to article $2", "Imagem $1 ligada ao artigo $2");
regGS("Image $1 unlinked from $2", "Imagem $1 retirada ao artigo $2");
regGS("The image $1 has been added.", "Imagem $1 foi adicionada");
regGS("Image $1 deleted", "Imagem $1 apagada");
regGS("Publication $1 changed", "$1 alterada(o)");
regGS("Publication $1 deleted", "A Publicação $1 foi Apagada");
regGS("Publication $1 added", "Foi Criada a Publicação $1");
regGS("Issue $1 from publication $2 deleted", "Edição $1 da Publicação $2 foi Eliminada");
regGS("Issue $1 added in publication $2", "Edição $1 adicionada na Publicação $2");
regGS("The article type $1 has been deleted.", "Tipo de Artigo $1 foi eliminado");
regGS("The article type $1 has been added.", "O Tipo de Artigo $1 foi adicionado");
regGS("Article type field $1 created", "Campo $1 foi criado");
regGS("Article type field $1 deleted", "Campo $1 foi eliminado");
regGS("Language $1 added", "O Idioma $1 foi adicionado");
regGS("Language $1 deleted", "O Idioma $1 foi eliminado");
regGS("Language $1 modified", "Idioma $1 actualizado");
regGS("Country $1 added", "Pais $1 foi criado com sucesso");
regGS("Country $1 deleted", "O Pais $1 foi eliminado.");
regGS("Country name $1 changed", "O Nome do Pais $1 foi Alterado");
regGS("The user account $1 has been deleted.", "Utilizador $1 foi eliminado");
regGS("Password changed for $1", "Palavra-Passe de $1 foi alterada");
regGS("User account $1 created", "Utilizador $1 foi criado");
regGS("Template $1 uploaded", "O modelo $1 foi transferido");
?>

==> campsite-2.6.1.tbz: campsite/www-common/html/priv/lang/pt/api.php <==
<?php 
regGS("Template $1 no longer exists!", "");
regGS("The file uploaded is not an image.", "");
regGS("Field $1 updated", "");
regGS("Could not delete record from the database.", "");
regGS("template path", "");
regGS("short names", "");
regGS("Unable to fetch image from remote server.", "");
regGS("The article type field $1 has been renamed to $2.", "");
regGS("The article type $1 has been renamed to $2.", "");
regGS("Article type field $1 changed", "");
regGS("Article Type $1 translation updated", "");
regGS("The IP address group $1 has been deleted.", "O grupo de ip's $1 foi eliminado.");
regGS("IP Group $1 added for user $2", "O grupo de ip's $1 foi adicionado para o utilizador $2");
regGS("User permissions for $1 changed", "As permissões para o utilizador $1 foram alteradas");
regGS("Section $1 deleted. (Issue: $2, Publication: $3)", "Secção $1 eliminada. (Edição $2, Publicação: $3)");
regGS("Section $1 added. (Issue: $2, Publication: $3)", "Secção $1 adicionada. (Edição $2, Publicação: $3)");
regGS("Issue $1 changed status to $2", "O Estado da edição $1 foi alterado para $2");
regGS("User type $1 deleted", "Tipo de utilizador $1 eliminado.");
regGS("User type $1 added", "Tipo de utilizador $1 adicionado.");
regGS("Topic $1 added to article", "Tema $1 foi adicionado ao artigo");
regGS("Last", "Ultimo");
regGS("First", "Primeiro");
regGS("Changed image properties of $1", "Alterando as informações da imagem $1");
regGS("Article topic $1 deleted", "O tema $1 do artigo foi eliminado");
regGS("Article #$1 \"$2\" ($3) created.", "Artigo #$1 \"$2\" ($3) criado.");
regGS("Article #$1 \"$2\" ($3) translated to \"$5\" ($4)", "Artigo #$1 \"$2\" ($3) traduzido para \"$5\" ($4)");
regGS("Article #$1 \"$2\" ($3) copied to Article #$3. ", "Artigo #$1 \"$2\" ($3) copiado para #$3.");
regGS("Article #$1: \"$2\" status changed from $3 to $4.", "Estado do Artigo #$1: \"$2\" alterado de $3 para $4.");
regGS("Article #$1: \"$2\" ($3) deleted.", "Artigo #$1: \"$2\" ($3) eliminado.");
regGS("Single-line Text", "Texto");
regGS("Multi-line Text with WYSIWYG", "Corpo do artigo");
regGS("The default subscription time for $1 has been added.", "Foi adiciondo um tempo de Assinatura para $1 ");
regGS("Image $1 linked to article $2", "Imagem $1 ligada ao artigo $2");
regGS("Image $1 unlinked from $2", "Imagem $1 retirada ao artigo $2");
regGS("The image $1 has been added.", "Imagem $1 foi adicionada");
regGS("Image $1 deleted", "Imagem $1 apagada");
regGS("Publication $1 changed", "$1 alterada(o)");
regGS("Publication $1 deleted", "A Publicação $1 foi Apagada");
regGS("Publication $1 added", "Foi Criada a Publicação $1");
regGS("Issue $1 from publication $2 deleted", "Edição $1 da Publicação $2 foi Eliminada");
regGS("Issue $1 added in publication $2", "Edição $1 adicionada na Publicação $2");
regGS("The article type $1 has been deleted.", "Tipo de Artigo $1 foi eliminado");
regGS("The article type $1 has been added.", "O Tipo de Artigo $1 foi adicionado");
regGS("Article type field $1 created", "Campo $1 foi criado");
regGS("Article type field $1 deleted", "Campo $1 foi eliminado");
regGS("Language $1 added", "O Idioma $1 foi adicionado");
regGS("Language $1 deleted", "O Idioma $1 foi eliminado");
regGS("Language $1 modified", "Idioma $1 actualizado");
regGS("Country $1 added", "Pais $1 foi criado com sucesso");
regGS("Country $1 deleted", "O Pais $1 foi eliminado.");
regGS("Country name $1 changed", "O Nome do Pais $1 foi Alterado");
regGS("The user account $1 has been deleted.", "Utilizador $1 foi eliminado");
regGS("Password changed for $1", "Palavra-Passe de $1 foi alterada");
regGS("User account $1 created", "Utilizador $1 foi criado");
regGS("Template $1 uploaded", "O modelo $1 foi transferido");
regGS("URL \"$1\" is invalid or is not an image.", "O Endereço \"$1\" não é uma imagem ou é inválido");
regGS("URL \"$1\" is not an image.", "O Endereço \"$1\" não é uma imagem");
regGS("Topic $1 added", "Artigo Adicionado ao Tema $1.");
regGS("Topic $1 deleted", "Tema $1 Apagado");
regGS("Topic $1 updated", "Tema $1 Alterado.");
?>
